_`umbra.ui.completers`
======================

.. automodule:: umbra.ui.completers

Module Attributes
-----------------

.. attribute:: umbra.ui.completers.LOGGER

Classes
-------

.. autoclass:: DefaultCompleter
	:show-inheritance:
	:members:

